## Ver. 1.5.5 - 2016-Nov-20

Bug fix release with improvements in the Http client for streaming
requests. Importantly, python 3.6 passes all tests.

* Python 3.6-dev tests passing on travis
* Fixed HttpTestClient [7641cc5](https://github.com/quantmind/pulsar/commit/7641cc5acb11e9fb44d5e814fe3bba39fdefc013)
* Abort connection if not closing within 3 seconds
* Added ``done`` method to ``ProtocolConsumer``
* Don't detach connection when streaming and response is done already [8be1caa](https://github.com/quantmind/pulsar/commit/8be1caaa18cba8ca40de822e657e3a155250aed7)
* Install ``bench`` command for benchmarking tests
* Fixed multi label test run


## Ver. 1.5.4 - 2016-Nov-05

This release is important if you need to upload large files via HTTP.
The new ``stream_buffer`` configuration parameter helps you in this respect.

* Added ``stream_buffer`` configuration parameter for controlling the maximum size of stream buffers
  [14d6f2e](https://github.com/quantmind/pulsar/commit/14d6f2e7d1f54795ab5fe8f15ed97dd5eb6f62c5)
* Allow for clean removal of callbacks in channels by raising the ``CallbackError`` exception
  [d7b9ff1](https://github.com/quantmind/pulsar/commit/d7b9ff177f76abd5c08859319571dcabe852cf9b)
* Documentation fixes
* OAuth test coverage


## Ver. 1.5.3 - 2016-Oct-31

This is a minor release with documentation fixes and channels improvements.

* Refactored test documentation
* Added Channels documentation
* Better handling of channels disconnections
* Increased test coverage by 0.5%


## Ver. 1.5.2 - 2016-Oct-23

Bug fix release, version 1.5.1 has a regression bug on the redis pub-sub client.
Disregard that version in favor of this one.


## Ver. 1.5.1 - 2016-Oct-23

This minor release brings ``Channels`` to pulsar.
Channels are a better way to manage publish/subscribe clients.
Channels use ``events`` to create namespaces which limit the
number of channels a client needs to subscribe to. A ``pubsub``
client can ``register`` to one or more event from a given channel.

This feature is in initial phase of development but stable.
Documentation will follow.


## Ver. 1.5.0 - 2016-Oct-11

This version brings several improvements and enhancements in the internal API.
It is broadly compatible with the 1.4 series with the exception of the media component in the
WSGI strings. Importantly, multi-processing is handled directly by asyncio
rather than the [multiprocessing](https://docs.python.org/3/library/multiprocessing.html) module.
It is still possible to use the ``multiprocessing`` module via ``--concurrency multi``
command line/config flag.
Support for [uvloop](https://github.com/MagicStack/uvloop) has been added.
To use the this third party event loop, pass the ``--io uv`` flag in the command line.

* Several internal changes for better asyncio API support, dropped all private methods
* Process based actors are created using asyncio subprocess API
* Actor based on the multiprocessing module are created via the ``multi`` concurrency flag
* Added the ``bench`` setup.py command [#247](https://github.com/quantmind/pulsar/issues/247)
* Added ``pulsar.create_future`` function, a shortcut for ``loop.create_future``
* Added support for [uvloop](https://github.com/MagicStack/uvloop)
* Removed tweet example and created a new repository [pulsar-twitter](https://github.com/quantmind/pulsar-twitter)
* Removed ``require`` script from wsgi media and refactoring [#239](https://github.com/quantmind/pulsar/issues/239)
* Test.wait only support ``assertRaises`` [#235](https://github.com/quantmind/pulsar/issues/235)
* Removed ``yield from`` from all tests
* No more docs in http://pythonhosted.org/pulsar/
